/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct RootObj RootObj;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__Gl8s23LA3EFz4kIlya9ameg tySequence__Gl8s23LA3EFz4kIlya9ameg;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__eJWcQvhuN2q0rM6THoByqQ tySequence__eJWcQvhuN2q0rM6THoByqQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw;
typedef struct tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ;
typedef struct tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tySequence__wOOG2VKbTPdEdoo59cOatCw tySequence__wOOG2VKbTPdEdoo59cOatCw;
typedef struct tySequence__UyAyNhiI7poI9amqn9aUHktQ tySequence__UyAyNhiI7poI9amqn9aUHktQ;
typedef struct tyObject_TBlock__65dcPwuICorQ6X0g9a7oKkQ tyObject_TBlock__65dcPwuICorQ6X0g9a7oKkQ;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyTuple__VJYnlz9ax09cmmFsZGV9axIWg tyTuple__VJYnlz9ax09cmmFsZGV9axIWg;
typedef struct tyTuple__5pg9aIYdyrJM6GlDgyTDumg tyTuple__5pg9aIYdyrJM6GlDgyTDumg;
typedef struct tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA;
typedef struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A tyTuple__JfHvHzMrhKkWAUvQKe0i1A;
typedef struct tyObject_Env_vmdefdotnim_vmdef___diB2NTuAIWY0FO9c5IUJRGg tyObject_Env_vmdefdotnim_vmdef___diB2NTuAIWY0FO9c5IUJRGg;
typedef struct tySequence__qoz9b2fDIpsvVqgQYTLWcFA tySequence__qoz9b2fDIpsvVqgQYTLWcFA;
typedef struct tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA;
typedef struct tyTuple__0y4YQo9b9byJ83c0H89bBtdRw tyTuple__0y4YQo9b9byJ83c0H89bBtdRw;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef NU8 tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ;
typedef NU8 tySet_tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw {
NF tEnter;
tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ* tos;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tySequence__YdLNCDKYeipzJx3I8Xw82Q* code;
tySequence__Gl8s23LA3EFz4kIlya9ameg* debug;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* globals;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constants;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentExceptionA;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentExceptionB;
NI exceptionInstr;
tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw* prc;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* callsite;
tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ mode;
tySet_tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA features;
NIM_BOOL traceActive;
NI loopIterations;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw comesFromHeuristic;
tySequence__eJWcQvhuN2q0rM6THoByqQ* callbacks;
NimStringDesc* errorFlag;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
NI oldErrorCount;
tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw profiler;
NI* templInstCounter;
tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g* vmstateDiff;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg procToCodePos;
};
struct tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw {
tySequence__wOOG2VKbTPdEdoo59cOatCw* blocks;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tySequence__UyAyNhiI7poI9amqn9aUHktQ* regInfo;
};
struct tyObject_TBlock__65dcPwuICorQ6X0g9a7oKkQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* label;
tySequence__qwqHTkRvwhrRyENtudHQ7g* fixups;
};
typedef NU8 tyEnum_TSlotKind__MaOFY039asb5DVSmSlOHGtA;
struct tyTuple__VJYnlz9ax09cmmFsZGV9axIWg {
NIM_BOOL Field0;
tyEnum_TSlotKind__MaOFY039asb5DVSmSlOHGtA Field1;
};
typedef NU8 tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
void* ClE_0;
} tyProc__vkuGXw0bPP9b9cpazTHQY9bqg;
struct tyTuple__5pg9aIYdyrJM6GlDgyTDumg {
NimStringDesc* Field0;
tyProc__vkuGXw0bPP9b9cpazTHQY9bqg Field1;
};
struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A {
void* Field0;
tyObject_Env_vmdefdotnim_vmdef___diB2NTuAIWY0FO9c5IUJRGg* Field1;
};
struct tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc;
tySequence__qoz9b2fDIpsvVqgQYTLWcFA* slots;
tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ* next;
NI comesFrom;
tySequence__qwqHTkRvwhrRyENtudHQ7g* safePoints;
};
typedef NU8 tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg;
struct tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA {
tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg kind;
union{
NI64 intVal;
NF floatVal;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node;
tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA* regAddr;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** nodeAddr;
};
};
struct tyTuple__0y4YQo9b9byJ83c0H89bBtdRw {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field1;
};
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef NU8 tyEnum_TOpcode__6Md36HXDC8kz9aZEdeQ4KoQ;
struct tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA {
NI ra;
NI rb;
NI rc;
tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA* slots;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentException;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw currentLineInfo;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  TGenericSeq Sup;
  NU64 data[SEQ_DECL_SIZE];
};
struct tySequence__Gl8s23LA3EFz4kIlya9ameg {
  TGenericSeq Sup;
  tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__wOOG2VKbTPdEdoo59cOatCw {
  TGenericSeq Sup;
  tyObject_TBlock__65dcPwuICorQ6X0g9a7oKkQ data[SEQ_DECL_SIZE];
};
struct tySequence__UyAyNhiI7poI9amqn9aUHktQ {
  TGenericSeq Sup;
  tyTuple__VJYnlz9ax09cmmFsZGV9axIWg data[SEQ_DECL_SIZE];
};
struct tySequence__eJWcQvhuN2q0rM6THoByqQ {
  TGenericSeq Sup;
  tyTuple__5pg9aIYdyrJM6GlDgyTDumg data[SEQ_DECL_SIZE];
};
struct tySequence__qoz9b2fDIpsvVqgQYTLWcFA {
  TGenericSeq Sup;
  tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA data[SEQ_DECL_SIZE];
};
struct tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g {
  TGenericSeq Sup;
  tyTuple__0y4YQo9b9byJ83c0H89bBtdRw data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
static N_NIMCALL(void, Marker_tySequence__YdLNCDKYeipzJx3I8Xw82Q)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__Gl8s23LA3EFz4kIlya9ameg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__qwqHTkRvwhrRyENtudHQ7g)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__wOOG2VKbTPdEdoo59cOatCw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__UyAyNhiI7poI9amqn9aUHktQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__JDRtrAs1KGboZOsEqZ5HdQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__eJWcQvhuN2q0rM6THoByqQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__qoz9b2fDIpsvVqgQYTLWcFA)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__GROwhbu9aXZcBNGpHQVFqow)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__E8pi9b5QNahsURYzXMjh3qw)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__4IKTvAXRLrZvs9cUNEP7Z8w)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNode__ast_3289)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(void, nimGCunrefRC1)(void* p);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
extern TNimType NTItpasscontext__dmp6pRpfXxJk6gIZHkm7dw_;
N_LIB_PRIVATE TNimType NTItctx__CRPlhL1hATwZc5hefTGOQQ_;
N_LIB_PRIVATE TNimType NTItinstrtype__wMtfD88jmrPZwfzTH9c8e9cA_;
N_LIB_PRIVATE TNimType NTIseqLtinstrT__YdLNCDKYeipzJx3I8Xw82Q_;
extern TNimType NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_;
N_LIB_PRIVATE TNimType NTIseqLtlineinfoT__Gl8s23LA3EFz4kIlya9ameg_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
extern TNimType NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTIpproc58objecttype__1XP6mUlNhJdzLnDeBOqcVw_;
N_LIB_PRIVATE TNimType NTItblock__65dcPwuICorQ6X0g9a7oKkQ_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
N_LIB_PRIVATE TNimType NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_;
N_LIB_PRIVATE TNimType NTIseqLtblockT__wOOG2VKbTPdEdoo59cOatCw_;
N_LIB_PRIVATE TNimType NTItupleLinuse58bool_kind58tslotkindT__VJYnlz9ax09cmmFsZGV9axIWg_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTItslotkind__MaOFY039asb5DVSmSlOHGtA_;
N_LIB_PRIVATE TNimType NTIseqLtupleLinuse58bool_kind58tslotkindTT__UyAyNhiI7poI9amqn9aUHktQ_;
N_LIB_PRIVATE TNimType NTIpproc__JDRtrAs1KGboZOsEqZ5HdQ_;
N_LIB_PRIVATE TNimType NTItevalmode__iWSxkwmhTDY7fh9aYmp69akQ_;
N_LIB_PRIVATE TNimType NTItsandboxflag__6jKj8dTCDIUGegA1P2RahA_;
N_LIB_PRIVATE TNimType NTItsandboxflags__lZQaLRmr1Qm22IjKsf9c5bA_;
N_LIB_PRIVATE TNimType NTItupleLkey58string_value58vmcallbackT__5pg9aIYdyrJM6GlDgyTDumg_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTIvmcallback__vkuGXw0bPP9b9cpazTHQY9bqg_;
extern TNimType NTIpointer__vr5DoT1jILTGdRlYv1OYpw_;
extern TNimType NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_;
N_LIB_PRIVATE TNimType NTIseqLtupleLkey58string_value58vmcallbackTT__eJWcQvhuN2q0rM6THoByqQ_;
extern TNimType NTIidentcache__6ZZ9cf5acLVYxUxl0ehlA1g_;
extern TNimType NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_;
extern TNimType NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_;
N_LIB_PRIVATE TNimType NTIprofiler__vPk6nUD8QeNW2bHH4WZfpw_;
extern TNimType NTIfloat__w9bl9a1ul9ctRJWiMl9cNnIMvg_;
N_LIB_PRIVATE TNimType NTItstackframe__0GloFoQJxIWYG3W9cguBcAQ_;
N_LIB_PRIVATE TNimType NTItfullreg__5wJdjCgIXFtQUOFYtApLgA_;
N_LIB_PRIVATE TNimType NTItregisterkind__drcwtBjsw5cM6mbg9chBM9bg_;
TNimNode* NimDT___5wJdjCgIXFtQUOFYtApLgA_kind[7];
extern TNimType NTIbiggestint__Aav8dQoMlCFnZRxA0IhTHQ_;
N_LIB_PRIVATE TNimType NTIptrtfullreg__pX9bsRnb7gcWmGZmZ6MjgOg_;
extern TNimType NTIptrpnode__OjXsXEncjU0h7ZCAQTmgaw_;
N_LIB_PRIVATE TNimType NTIseqLtfullregT__qoz9b2fDIpsvVqgQYTLWcFA_;
N_LIB_PRIVATE TNimType NTIpstackframe__GROwhbu9aXZcBNGpHQVFqow_;
extern TNimType NTIrefint__9ai78kkwqt3gikTN9cpHKUVg_;
N_LIB_PRIVATE TNimType NTILpsym_pnodeT__0y4YQo9b9byJ83c0H89bBtdRw_;
N_LIB_PRIVATE TNimType NTIseqLLpsym_pnodeTT__ztPIC2M9bqhs0KjYuE9c9cN8g_;
N_LIB_PRIVATE TNimType NTItable__7ACYz5IhOEwzTBvwo6BO9bg_;
extern TNimType NTInimver__47w2DboNEPf69aPgubZdd7Q_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__E8pi9b5QNahsURYzXMjh3qw_;
N_LIB_PRIVATE TNimType NTIpevalcontext__4IKTvAXRLrZvs9cUNEP7Z8w_;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
N_LIB_PRIVATE TNimType NTItopcode__6Md36HXDC8kz9aZEdeQ4KoQ_;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
static N_NIMCALL(void, Marker_tySequence__YdLNCDKYeipzJx3I8Xw82Q)(void* p, NI op) {
	tySequence__YdLNCDKYeipzJx3I8Xw82Q* a;
	NI T1_;
	a = (tySequence__YdLNCDKYeipzJx3I8Xw82Q*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__Gl8s23LA3EFz4kIlya9ameg)(void* p, NI op) {
	tySequence__Gl8s23LA3EFz4kIlya9ameg* a;
	NI T1_;
	a = (tySequence__Gl8s23LA3EFz4kIlya9ameg*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__qwqHTkRvwhrRyENtudHQ7g)(void* p, NI op) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g* a;
	NI T1_;
	a = (tySequence__qwqHTkRvwhrRyENtudHQ7g*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__wOOG2VKbTPdEdoo59cOatCw)(void* p, NI op) {
	tySequence__wOOG2VKbTPdEdoo59cOatCw* a;
	NI T1_;
	a = (tySequence__wOOG2VKbTPdEdoo59cOatCw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].label, op);
	nimGCvisit((void*)a->data[T1_].fixups, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__UyAyNhiI7poI9amqn9aUHktQ)(void* p, NI op) {
	tySequence__UyAyNhiI7poI9amqn9aUHktQ* a;
	NI T1_;
	a = (tySequence__UyAyNhiI7poI9amqn9aUHktQ*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tyRef__JDRtrAs1KGboZOsEqZ5HdQ)(void* p, NI op) {
	tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw* a;
	a = (tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw*)p;
	nimGCvisit((void*)(*a).blocks, op);
	nimGCvisit((void*)(*a).sym, op);
	nimGCvisit((void*)(*a).regInfo, op);
}
static N_NIMCALL(void, Marker_tySequence__eJWcQvhuN2q0rM6THoByqQ)(void* p, NI op) {
	tySequence__eJWcQvhuN2q0rM6THoByqQ* a;
	NI T1_;
	a = (tySequence__eJWcQvhuN2q0rM6THoByqQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1.ClE_0, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__qoz9b2fDIpsvVqgQYTLWcFA)(void* p, NI op) {
	tySequence__qoz9b2fDIpsvVqgQYTLWcFA* a;
	NI T1_;
	a = (tySequence__qoz9b2fDIpsvVqgQYTLWcFA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	switch (a->data[T1_].kind) {
	case ((tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg) 0):
	break;
	case ((tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg) 2):
	break;
	case ((tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg) 3):
	break;
	case ((tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg) 1):
	nimGCvisit((void*)a->data[T1_].node, op);
	break;
	case ((tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg) 4):
	break;
	case ((tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg) 5):
	break;
	} 
	}
}
static N_NIMCALL(void, Marker_tyRef__GROwhbu9aXZcBNGpHQVFqow)(void* p, NI op) {
	tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ* a;
	a = (tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ*)p;
	nimGCvisit((void*)(*a).prc, op);
	nimGCvisit((void*)(*a).slots, op);
	nimGCvisit((void*)(*a).next, op);
	nimGCvisit((void*)(*a).safePoints, op);
}
static N_NIMCALL(void, Marker_tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g)(void* p, NI op) {
	tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g* a;
	NI T1_;
	a = (tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__E8pi9b5QNahsURYzXMjh3qw)(void* p, NI op) {
	tySequence__E8pi9b5QNahsURYzXMjh3qw* a;
	NI T1_;
	a = (tySequence__E8pi9b5QNahsURYzXMjh3qw*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tyRef__4IKTvAXRLrZvs9cUNEP7Z8w)(void* p, NI op) {
	tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* a;
	a = (tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ*)p;
	nimGCvisit((void*)(*a).Sup.idgen, op);
	nimGCvisit((void*)(*a).code, op);
	nimGCvisit((void*)(*a).debug, op);
	nimGCvisit((void*)(*a).globals, op);
	nimGCvisit((void*)(*a).constants, op);
	nimGCvisit((void*)(*a).types, op);
	nimGCvisit((void*)(*a).currentExceptionA, op);
	nimGCvisit((void*)(*a).currentExceptionB, op);
	nimGCvisit((void*)(*a).prc, op);
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).callsite, op);
	nimGCvisit((void*)(*a).callbacks, op);
	nimGCvisit((void*)(*a).errorFlag, op);
	nimGCvisit((void*)(*a).cache, op);
	nimGCvisit((void*)(*a).config, op);
	nimGCvisit((void*)(*a).graph, op);
	nimGCvisit((void*)(*a).profiler.tos, op);
	nimGCvisit((void*)(*a).templInstCounter, op);
	nimGCvisit((void*)(*a).vmstateDiff, op);
	nimGCvisit((void*)(*a).procToCodePos.data, op);
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5264(p);
	decRef__system_5309(T1_);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefRC1)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5264(p);
	decRef__system_5309(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ*, newCtx__vmdef_367)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* result;
	tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* T1_;
	tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw* T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ*) newObj((&NTIpevalcontext__4IKTvAXRLrZvs9cUNEP7Z8w_), sizeof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ));
	(*T1_).Sup.Sup.m_type = (&NTItctx__CRPlhL1hATwZc5hefTGOQQ_);
	if ((*T1_).code) { nimGCunrefNoCycle((*T1_).code); (*T1_).code = NIM_NIL; }
	if ((*T1_).debug) { nimGCunrefNoCycle((*T1_).debug); (*T1_).debug = NIM_NIL; }
	asgnRef((void**) (&(*T1_).globals), newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126)));
	asgnRef((void**) (&(*T1_).constants), newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115)));
	if ((*T1_).types) { nimGCunrefNoCycle((*T1_).types); (*T1_).types = NIM_NIL; }
	T2_ = NIM_NIL;
	T2_ = (tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw*) newObj((&NTIpproc__JDRtrAs1KGboZOsEqZ5HdQ_), sizeof(tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw));
	if ((*T2_).blocks) { nimGCunrefNoCycle((*T2_).blocks); (*T2_).blocks = NIM_NIL; }
	asgnRef((void**) (&(*T1_).prc), T2_);
	asgnRef((void**) (&(*T1_).module), module);
	(*T1_).loopIterations = (*(*g).config).maxLoopIterationsVM;
	(*T1_).comesFromHeuristic = unknownLineInfo__lineinfos_284;
	if ((*T1_).callbacks) { nimGCunrefRC1((*T1_).callbacks); (*T1_).callbacks = NIM_NIL; }
	asgnRef((void**) (&(*T1_).errorFlag), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).cache), cache);
	asgnRef((void**) (&(*T1_).config), (*g).config);
	asgnRef((void**) (&(*T1_).graph), g);
	asgnRef((void**) (&(*T1_).Sup.idgen), idgen);
	result = T1_;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(NI, registerCallback__vmdef_518)(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* c, NimStringDesc* name, tyProc__vkuGXw0bPP9b9cpazTHQY9bqg callback) {
	NI result;
	NI T1_;
	tyTuple__5pg9aIYdyrJM6GlDgyTDumg T2_;
	NI T3_;
	NimStringDesc* T4_;
	result = (NI)0;
	T1_ = ((*c).callbacks ? (*c).callbacks->Sup.len : 0);
	result = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__5pg9aIYdyrJM6GlDgyTDumg));
	T2_.Field0 = copyString(name);
	T2_.Field1.ClE_0 = callback.ClE_0;
	T2_.Field1.ClP_0 = callback.ClP_0;
	asgnRef((void**) (&(*c).callbacks), (tySequence__eJWcQvhuN2q0rM6THoByqQ*) incrSeqV3((TGenericSeq*)((*c).callbacks), (&NTIseqLtupleLkey58string_value58vmcallbackTT__eJWcQvhuN2q0rM6THoByqQ_)));
	T3_ = (*c).callbacks->Sup.len++;
	T4_ = NIM_NIL;
	T4_ = (*c).callbacks->data[T3_].Field0; (*c).callbacks->data[T3_].Field0 = copyStringRC1(T2_.Field0);
	if (T4_) nimGCunrefNoCycle(T4_);
	asgnRef((void**) (&(*c).callbacks->data[T3_].Field1.ClE_0), T2_.Field1.ClE_0);
	(*c).callbacks->data[T3_].Field1.ClP_0 = T2_.Field1.ClP_0;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, refresh__vmdef_510)(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw* T1_;
	asgnRef((void**) (&(*c).module), module);
	T1_ = NIM_NIL;
	T1_ = (tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw*) newObj((&NTIpproc__JDRtrAs1KGboZOsEqZ5HdQ_), sizeof(tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw));
	if ((*T1_).blocks) { nimGCunrefNoCycle((*T1_).blocks); (*T1_).blocks = NIM_NIL; }
	asgnRef((void**) (&(*c).prc), T1_);
	(*c).loopIterations = (*(*c).config).maxLoopIterationsVM;
	asgnRef((void**) (&(*c).Sup.idgen), idgen);
}
N_LIB_PRIVATE N_NIMCALL(void, atmvmdefdotnim_DatInit000)(void) {
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_2_26[26];
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_3_3[3];
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_4_2[2];
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_5_2[2];
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_6_9[9];
NI TM__3mpNz9a6xejw41nkGLvLInw_8;
static char* NIM_CONST TM__3mpNz9a6xejw41nkGLvLInw_7[9] = {
"slotEmpty", 
"slotFixedVar", 
"slotFixedLet", 
"slotTempUnknown", 
"slotTempInt", 
"slotTempFloat", 
"slotTempStr", 
"slotTempComplex", 
"slotTempPerm"};
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_9_5[5];
NI TM__3mpNz9a6xejw41nkGLvLInw_11;
static char* NIM_CONST TM__3mpNz9a6xejw41nkGLvLInw_10[5] = {
"emRepl", 
"emConst", 
"emOptimize", 
"emStaticExpr", 
"emStaticStmt"};
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_12_2[2];
NI TM__3mpNz9a6xejw41nkGLvLInw_14;
static char* NIM_CONST TM__3mpNz9a6xejw41nkGLvLInw_13[2] = {
"allowCast", 
"allowInfiniteLoops"};
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_15_2[2];
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_16_2[2];
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_17_2[2];
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_18_5[5];
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_19_6[6];
NI TM__3mpNz9a6xejw41nkGLvLInw_21;
static char* NIM_CONST TM__3mpNz9a6xejw41nkGLvLInw_20[6] = {
"rkNone", 
"rkNode", 
"rkInt", 
"rkFloat", 
"rkRegisterAddr", 
"rkNodeAddr"};
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_22_2[2];
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_23_2[2];
static TNimNode* TM__3mpNz9a6xejw41nkGLvLInw_24_193[193];
NI TM__3mpNz9a6xejw41nkGLvLInw_26;
static char* NIM_CONST TM__3mpNz9a6xejw41nkGLvLInw_25[193] = {
"opcEof", 
"opcRet", 
"opcYldYoid", 
"opcYldVal", 
"opcAsgnInt", 
"opcAsgnFloat", 
"opcAsgnRef", 
"opcAsgnComplex", 
"opcCastIntToFloat32", 
"opcCastIntToFloat64", 
"opcCastFloatToInt32", 
"opcCastFloatToInt64", 
"opcCastPtrToInt", 
"opcCastIntToPtr", 
"opcFastAsgnComplex", 
"opcNodeToReg", 
"opcLdArr", 
"opcLdArrAddr", 
"opcWrArr", 
"opcLdObj", 
"opcLdObjAddr", 
"opcWrObj", 
"opcAddrReg", 
"opcAddrNode", 
"opcLdDeref", 
"opcWrDeref", 
"opcWrStrIdx", 
"opcLdStrIdx", 
"opcLdStrIdxAddr", 
"opcSlice", 
"opcAddInt", 
"opcAddImmInt", 
"opcSubInt", 
"opcSubImmInt", 
"opcLenSeq", 
"opcLenStr", 
"opcLenCstring", 
"opcIncl", 
"opcInclRange", 
"opcExcl", 
"opcCard", 
"opcMulInt", 
"opcDivInt", 
"opcModInt", 
"opcAddFloat", 
"opcSubFloat", 
"opcMulFloat", 
"opcDivFloat", 
"opcShrInt", 
"opcShlInt", 
"opcAshrInt", 
"opcBitandInt", 
"opcBitorInt", 
"opcBitxorInt", 
"opcAddu", 
"opcSubu", 
"opcMulu", 
"opcDivu", 
"opcModu", 
"opcEqInt", 
"opcLeInt", 
"opcLtInt", 
"opcEqFloat", 
"opcLeFloat", 
"opcLtFloat", 
"opcLeu", 
"opcLtu", 
"opcEqRef", 
"opcEqNimNode", 
"opcSameNodeType", 
"opcXor", 
"opcNot", 
"opcUnaryMinusInt", 
"opcUnaryMinusFloat", 
"opcBitnotInt", 
"opcEqStr", 
"opcLeStr", 
"opcLtStr", 
"opcEqSet", 
"opcLeSet", 
"opcLtSet", 
"opcMulSet", 
"opcPlusSet", 
"opcMinusSet", 
"opcConcatStr", 
"opcContainsSet", 
"opcRepr", 
"opcSetLenStr", 
"opcSetLenSeq", 
"opcIsNil", 
"opcOf", 
"opcIs", 
"opcSubStr", 
"opcParseFloat", 
"opcConv", 
"opcCast", 
"opcQuit", 
"opcInvalidField", 
"opcNarrowS", 
"opcNarrowU", 
"opcSignExtend", 
"opcAddStrCh", 
"opcAddStrStr", 
"opcAddSeqElem", 
"opcRangeChck", 
"opcNAdd", 
"opcNAddMultiple", 
"opcNKind", 
"opcNSymKind", 
"opcNIntVal", 
"opcNFloatVal", 
"opcNSymbol", 
"opcNIdent", 
"opcNGetType", 
"opcNStrVal", 
"opcNSigHash", 
"opcNGetSize", 
"opcNSetIntVal", 
"opcNSetFloatVal", 
"opcNSetSymbol", 
"opcNSetIdent", 
"opcNSetType", 
"opcNSetStrVal", 
"opcNNewNimNode", 
"opcNCopyNimNode", 
"opcNCopyNimTree", 
"opcNDel", 
"opcGenSym", 
"opcNccValue", 
"opcNccInc", 
"opcNcsAdd", 
"opcNcsIncl", 
"opcNcsLen", 
"opcNcsAt", 
"opcNctPut", 
"opcNctLen", 
"opcNctGet", 
"opcNctHasNext", 
"opcNctNext", 
"opcNodeId", 
"opcSlurp", 
"opcGorge", 
"opcParseExprToAst", 
"opcParseStmtToAst", 
"opcQueryErrorFlag", 
"opcNError", 
"opcNWarning", 
"opcNHint", 
"opcNGetLineInfo", 
"opcNCopyLineInfo", 
"opcNSetLineInfoLine", 
"opcNSetLineInfoColumn", 
"opcNSetLineInfoFile", 
"opcEqIdent", 
"opcStrToIdent", 
"opcGetImpl", 
"opcGetImplTransf", 
"opcEcho", 
"opcIndCall", 
"opcIndCallAsgn", 
"opcRaise", 
"opcNChild", 
"opcNSetChild", 
"opcCallSite", 
"opcNewStr", 
"opcTJmp", 
"opcFJmp", 
"opcJmp", 
"opcJmpBack", 
"opcBranch", 
"opcTry", 
"opcExcept", 
"opcFinally", 
"opcFinallyEnd", 
"opcNew", 
"opcNewSeq", 
"opcLdNull", 
"opcLdNullReg", 
"opcLdConst", 
"opcAsgnConst", 
"opcLdGlobal", 
"opcLdGlobalAddr", 
"opcLdGlobalDerefFFI", 
"opcLdGlobalAddrDerefFFI", 
"opcLdImmInt", 
"opcNBindSym", 
"opcNDynBindSym", 
"opcSetType", 
"opcTypeTrait", 
"opcMarshalLoad", 
"opcMarshalStore", 
"opcSymOwner", 
"opcSymIsInstantiationOf"};
static TNimNode TM__3mpNz9a6xejw41nkGLvLInw_0[286];
NTItctx__CRPlhL1hATwZc5hefTGOQQ_.size = sizeof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ);
NTItctx__CRPlhL1hATwZc5hefTGOQQ_.align = NIM_ALIGNOF(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ);
NTItctx__CRPlhL1hATwZc5hefTGOQQ_.kind = 17;
NTItctx__CRPlhL1hATwZc5hefTGOQQ_.base = (&NTItpasscontext__dmp6pRpfXxJk6gIZHkm7dw_);
TM__3mpNz9a6xejw41nkGLvLInw_2_26[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[1];
NTItinstrtype__wMtfD88jmrPZwfzTH9c8e9cA_.size = sizeof(NU64);
NTItinstrtype__wMtfD88jmrPZwfzTH9c8e9cA_.align = NIM_ALIGNOF(NU64);
NTItinstrtype__wMtfD88jmrPZwfzTH9c8e9cA_.kind = 44;
NTItinstrtype__wMtfD88jmrPZwfzTH9c8e9cA_.base = 0;
NTItinstrtype__wMtfD88jmrPZwfzTH9c8e9cA_.flags = 3;
NTIseqLtinstrT__YdLNCDKYeipzJx3I8Xw82Q_.size = sizeof(tySequence__YdLNCDKYeipzJx3I8Xw82Q*);
NTIseqLtinstrT__YdLNCDKYeipzJx3I8Xw82Q_.align = NIM_ALIGNOF(tySequence__YdLNCDKYeipzJx3I8Xw82Q*);
NTIseqLtinstrT__YdLNCDKYeipzJx3I8Xw82Q_.kind = 24;
NTIseqLtinstrT__YdLNCDKYeipzJx3I8Xw82Q_.base = (&NTItinstrtype__wMtfD88jmrPZwfzTH9c8e9cA_);
NTIseqLtinstrT__YdLNCDKYeipzJx3I8Xw82Q_.flags = 2;
NTIseqLtinstrT__YdLNCDKYeipzJx3I8Xw82Q_.marker = Marker_tySequence__YdLNCDKYeipzJx3I8Xw82Q;
TM__3mpNz9a6xejw41nkGLvLInw_0[1].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[1].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, code);
TM__3mpNz9a6xejw41nkGLvLInw_0[1].typ = (&NTIseqLtinstrT__YdLNCDKYeipzJx3I8Xw82Q_);
TM__3mpNz9a6xejw41nkGLvLInw_0[1].name = "code";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[2];
NTIseqLtlineinfoT__Gl8s23LA3EFz4kIlya9ameg_.size = sizeof(tySequence__Gl8s23LA3EFz4kIlya9ameg*);
NTIseqLtlineinfoT__Gl8s23LA3EFz4kIlya9ameg_.align = NIM_ALIGNOF(tySequence__Gl8s23LA3EFz4kIlya9ameg*);
NTIseqLtlineinfoT__Gl8s23LA3EFz4kIlya9ameg_.kind = 24;
NTIseqLtlineinfoT__Gl8s23LA3EFz4kIlya9ameg_.base = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
NTIseqLtlineinfoT__Gl8s23LA3EFz4kIlya9ameg_.flags = 2;
NTIseqLtlineinfoT__Gl8s23LA3EFz4kIlya9ameg_.marker = Marker_tySequence__Gl8s23LA3EFz4kIlya9ameg;
TM__3mpNz9a6xejw41nkGLvLInw_0[2].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[2].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, debug);
TM__3mpNz9a6xejw41nkGLvLInw_0[2].typ = (&NTIseqLtlineinfoT__Gl8s23LA3EFz4kIlya9ameg_);
TM__3mpNz9a6xejw41nkGLvLInw_0[2].name = "debug";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[2] = &TM__3mpNz9a6xejw41nkGLvLInw_0[3];
TM__3mpNz9a6xejw41nkGLvLInw_0[3].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[3].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, globals);
TM__3mpNz9a6xejw41nkGLvLInw_0[3].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[3].name = "globals";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[3] = &TM__3mpNz9a6xejw41nkGLvLInw_0[4];
TM__3mpNz9a6xejw41nkGLvLInw_0[4].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[4].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, constants);
TM__3mpNz9a6xejw41nkGLvLInw_0[4].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[4].name = "constants";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[4] = &TM__3mpNz9a6xejw41nkGLvLInw_0[5];
TM__3mpNz9a6xejw41nkGLvLInw_0[5].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[5].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, types);
TM__3mpNz9a6xejw41nkGLvLInw_0[5].typ = (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[5].name = "types";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[5] = &TM__3mpNz9a6xejw41nkGLvLInw_0[6];
TM__3mpNz9a6xejw41nkGLvLInw_0[6].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[6].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, currentExceptionA);
TM__3mpNz9a6xejw41nkGLvLInw_0[6].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[6].name = "currentExceptionA";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[6] = &TM__3mpNz9a6xejw41nkGLvLInw_0[7];
TM__3mpNz9a6xejw41nkGLvLInw_0[7].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[7].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, currentExceptionB);
TM__3mpNz9a6xejw41nkGLvLInw_0[7].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[7].name = "currentExceptionB";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[7] = &TM__3mpNz9a6xejw41nkGLvLInw_0[8];
TM__3mpNz9a6xejw41nkGLvLInw_0[8].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[8].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, exceptionInstr);
TM__3mpNz9a6xejw41nkGLvLInw_0[8].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[8].name = "exceptionInstr";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[8] = &TM__3mpNz9a6xejw41nkGLvLInw_0[9];
NTIpproc58objecttype__1XP6mUlNhJdzLnDeBOqcVw_.size = sizeof(tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw);
NTIpproc58objecttype__1XP6mUlNhJdzLnDeBOqcVw_.align = NIM_ALIGNOF(tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw);
NTIpproc58objecttype__1XP6mUlNhJdzLnDeBOqcVw_.kind = 18;
NTIpproc58objecttype__1XP6mUlNhJdzLnDeBOqcVw_.base = 0;
NTIpproc58objecttype__1XP6mUlNhJdzLnDeBOqcVw_.flags = 2;
TM__3mpNz9a6xejw41nkGLvLInw_3_3[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[11];
NTItblock__65dcPwuICorQ6X0g9a7oKkQ_.size = sizeof(tyObject_TBlock__65dcPwuICorQ6X0g9a7oKkQ);
NTItblock__65dcPwuICorQ6X0g9a7oKkQ_.align = NIM_ALIGNOF(tyObject_TBlock__65dcPwuICorQ6X0g9a7oKkQ);
NTItblock__65dcPwuICorQ6X0g9a7oKkQ_.kind = 18;
NTItblock__65dcPwuICorQ6X0g9a7oKkQ_.base = 0;
NTItblock__65dcPwuICorQ6X0g9a7oKkQ_.flags = 2;
TM__3mpNz9a6xejw41nkGLvLInw_4_2[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[13];
TM__3mpNz9a6xejw41nkGLvLInw_0[13].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[13].offset = offsetof(tyObject_TBlock__65dcPwuICorQ6X0g9a7oKkQ, label);
TM__3mpNz9a6xejw41nkGLvLInw_0[13].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[13].name = "label";
TM__3mpNz9a6xejw41nkGLvLInw_4_2[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[14];
NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_.size = sizeof(tySequence__qwqHTkRvwhrRyENtudHQ7g*);
NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_.align = NIM_ALIGNOF(tySequence__qwqHTkRvwhrRyENtudHQ7g*);
NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_.kind = 24;
NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_.base = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_.flags = 2;
NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_.marker = Marker_tySequence__qwqHTkRvwhrRyENtudHQ7g;
TM__3mpNz9a6xejw41nkGLvLInw_0[14].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[14].offset = offsetof(tyObject_TBlock__65dcPwuICorQ6X0g9a7oKkQ, fixups);
TM__3mpNz9a6xejw41nkGLvLInw_0[14].typ = (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[14].name = "fixups";
TM__3mpNz9a6xejw41nkGLvLInw_0[12].len = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[12].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[12].sons = &TM__3mpNz9a6xejw41nkGLvLInw_4_2[0];
NTItblock__65dcPwuICorQ6X0g9a7oKkQ_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[12];
NTIseqLtblockT__wOOG2VKbTPdEdoo59cOatCw_.size = sizeof(tySequence__wOOG2VKbTPdEdoo59cOatCw*);
NTIseqLtblockT__wOOG2VKbTPdEdoo59cOatCw_.align = NIM_ALIGNOF(tySequence__wOOG2VKbTPdEdoo59cOatCw*);
NTIseqLtblockT__wOOG2VKbTPdEdoo59cOatCw_.kind = 24;
NTIseqLtblockT__wOOG2VKbTPdEdoo59cOatCw_.base = (&NTItblock__65dcPwuICorQ6X0g9a7oKkQ_);
NTIseqLtblockT__wOOG2VKbTPdEdoo59cOatCw_.flags = 2;
NTIseqLtblockT__wOOG2VKbTPdEdoo59cOatCw_.marker = Marker_tySequence__wOOG2VKbTPdEdoo59cOatCw;
TM__3mpNz9a6xejw41nkGLvLInw_0[11].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[11].offset = offsetof(tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw, blocks);
TM__3mpNz9a6xejw41nkGLvLInw_0[11].typ = (&NTIseqLtblockT__wOOG2VKbTPdEdoo59cOatCw_);
TM__3mpNz9a6xejw41nkGLvLInw_0[11].name = "blocks";
TM__3mpNz9a6xejw41nkGLvLInw_3_3[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[15];
TM__3mpNz9a6xejw41nkGLvLInw_0[15].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[15].offset = offsetof(tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw, sym);
TM__3mpNz9a6xejw41nkGLvLInw_0[15].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[15].name = "sym";
TM__3mpNz9a6xejw41nkGLvLInw_3_3[2] = &TM__3mpNz9a6xejw41nkGLvLInw_0[16];
NTItupleLinuse58bool_kind58tslotkindT__VJYnlz9ax09cmmFsZGV9axIWg_.size = sizeof(tyTuple__VJYnlz9ax09cmmFsZGV9axIWg);
NTItupleLinuse58bool_kind58tslotkindT__VJYnlz9ax09cmmFsZGV9axIWg_.align = NIM_ALIGNOF(tyTuple__VJYnlz9ax09cmmFsZGV9axIWg);
NTItupleLinuse58bool_kind58tslotkindT__VJYnlz9ax09cmmFsZGV9axIWg_.kind = 18;
NTItupleLinuse58bool_kind58tslotkindT__VJYnlz9ax09cmmFsZGV9axIWg_.base = 0;
NTItupleLinuse58bool_kind58tslotkindT__VJYnlz9ax09cmmFsZGV9axIWg_.flags = 3;
TM__3mpNz9a6xejw41nkGLvLInw_5_2[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[18];
TM__3mpNz9a6xejw41nkGLvLInw_0[18].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[18].offset = offsetof(tyTuple__VJYnlz9ax09cmmFsZGV9axIWg, Field0);
TM__3mpNz9a6xejw41nkGLvLInw_0[18].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[18].name = "Field0";
TM__3mpNz9a6xejw41nkGLvLInw_5_2[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[19];
NTItslotkind__MaOFY039asb5DVSmSlOHGtA_.size = sizeof(tyEnum_TSlotKind__MaOFY039asb5DVSmSlOHGtA);
NTItslotkind__MaOFY039asb5DVSmSlOHGtA_.align = NIM_ALIGNOF(tyEnum_TSlotKind__MaOFY039asb5DVSmSlOHGtA);
NTItslotkind__MaOFY039asb5DVSmSlOHGtA_.kind = 14;
NTItslotkind__MaOFY039asb5DVSmSlOHGtA_.base = 0;
NTItslotkind__MaOFY039asb5DVSmSlOHGtA_.flags = 3;
for (TM__3mpNz9a6xejw41nkGLvLInw_8 = 0; TM__3mpNz9a6xejw41nkGLvLInw_8 < 9; TM__3mpNz9a6xejw41nkGLvLInw_8++) {
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_8+20].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_8+20].offset = TM__3mpNz9a6xejw41nkGLvLInw_8;
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_8+20].name = TM__3mpNz9a6xejw41nkGLvLInw_7[TM__3mpNz9a6xejw41nkGLvLInw_8];
TM__3mpNz9a6xejw41nkGLvLInw_6_9[TM__3mpNz9a6xejw41nkGLvLInw_8] = &TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_8+20];
}
TM__3mpNz9a6xejw41nkGLvLInw_0[29].len = 9; TM__3mpNz9a6xejw41nkGLvLInw_0[29].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[29].sons = &TM__3mpNz9a6xejw41nkGLvLInw_6_9[0];
NTItslotkind__MaOFY039asb5DVSmSlOHGtA_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[29];
TM__3mpNz9a6xejw41nkGLvLInw_0[19].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[19].offset = offsetof(tyTuple__VJYnlz9ax09cmmFsZGV9axIWg, Field1);
TM__3mpNz9a6xejw41nkGLvLInw_0[19].typ = (&NTItslotkind__MaOFY039asb5DVSmSlOHGtA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[19].name = "Field1";
TM__3mpNz9a6xejw41nkGLvLInw_0[17].len = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[17].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[17].sons = &TM__3mpNz9a6xejw41nkGLvLInw_5_2[0];
NTItupleLinuse58bool_kind58tslotkindT__VJYnlz9ax09cmmFsZGV9axIWg_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[17];
NTIseqLtupleLinuse58bool_kind58tslotkindTT__UyAyNhiI7poI9amqn9aUHktQ_.size = sizeof(tySequence__UyAyNhiI7poI9amqn9aUHktQ*);
NTIseqLtupleLinuse58bool_kind58tslotkindTT__UyAyNhiI7poI9amqn9aUHktQ_.align = NIM_ALIGNOF(tySequence__UyAyNhiI7poI9amqn9aUHktQ*);
NTIseqLtupleLinuse58bool_kind58tslotkindTT__UyAyNhiI7poI9amqn9aUHktQ_.kind = 24;
NTIseqLtupleLinuse58bool_kind58tslotkindTT__UyAyNhiI7poI9amqn9aUHktQ_.base = (&NTItupleLinuse58bool_kind58tslotkindT__VJYnlz9ax09cmmFsZGV9axIWg_);
NTIseqLtupleLinuse58bool_kind58tslotkindTT__UyAyNhiI7poI9amqn9aUHktQ_.flags = 2;
NTIseqLtupleLinuse58bool_kind58tslotkindTT__UyAyNhiI7poI9amqn9aUHktQ_.marker = Marker_tySequence__UyAyNhiI7poI9amqn9aUHktQ;
TM__3mpNz9a6xejw41nkGLvLInw_0[16].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[16].offset = offsetof(tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw, regInfo);
TM__3mpNz9a6xejw41nkGLvLInw_0[16].typ = (&NTIseqLtupleLinuse58bool_kind58tslotkindTT__UyAyNhiI7poI9amqn9aUHktQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[16].name = "regInfo";
TM__3mpNz9a6xejw41nkGLvLInw_0[10].len = 3; TM__3mpNz9a6xejw41nkGLvLInw_0[10].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[10].sons = &TM__3mpNz9a6xejw41nkGLvLInw_3_3[0];
NTIpproc58objecttype__1XP6mUlNhJdzLnDeBOqcVw_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[10];
NTIpproc__JDRtrAs1KGboZOsEqZ5HdQ_.size = sizeof(tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw*);
NTIpproc__JDRtrAs1KGboZOsEqZ5HdQ_.align = NIM_ALIGNOF(tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw*);
NTIpproc__JDRtrAs1KGboZOsEqZ5HdQ_.kind = 22;
NTIpproc__JDRtrAs1KGboZOsEqZ5HdQ_.base = (&NTIpproc58objecttype__1XP6mUlNhJdzLnDeBOqcVw_);
NTIpproc__JDRtrAs1KGboZOsEqZ5HdQ_.flags = 2;
NTIpproc__JDRtrAs1KGboZOsEqZ5HdQ_.marker = Marker_tyRef__JDRtrAs1KGboZOsEqZ5HdQ;
TM__3mpNz9a6xejw41nkGLvLInw_0[9].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[9].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, prc);
TM__3mpNz9a6xejw41nkGLvLInw_0[9].typ = (&NTIpproc__JDRtrAs1KGboZOsEqZ5HdQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[9].name = "prc";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[9] = &TM__3mpNz9a6xejw41nkGLvLInw_0[30];
TM__3mpNz9a6xejw41nkGLvLInw_0[30].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[30].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, module);
TM__3mpNz9a6xejw41nkGLvLInw_0[30].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[30].name = "module";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[10] = &TM__3mpNz9a6xejw41nkGLvLInw_0[31];
TM__3mpNz9a6xejw41nkGLvLInw_0[31].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[31].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, callsite);
TM__3mpNz9a6xejw41nkGLvLInw_0[31].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[31].name = "callsite";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[11] = &TM__3mpNz9a6xejw41nkGLvLInw_0[32];
NTItevalmode__iWSxkwmhTDY7fh9aYmp69akQ_.size = sizeof(tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ);
NTItevalmode__iWSxkwmhTDY7fh9aYmp69akQ_.align = NIM_ALIGNOF(tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ);
NTItevalmode__iWSxkwmhTDY7fh9aYmp69akQ_.kind = 14;
NTItevalmode__iWSxkwmhTDY7fh9aYmp69akQ_.base = 0;
NTItevalmode__iWSxkwmhTDY7fh9aYmp69akQ_.flags = 3;
for (TM__3mpNz9a6xejw41nkGLvLInw_11 = 0; TM__3mpNz9a6xejw41nkGLvLInw_11 < 5; TM__3mpNz9a6xejw41nkGLvLInw_11++) {
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_11+33].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_11+33].offset = TM__3mpNz9a6xejw41nkGLvLInw_11;
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_11+33].name = TM__3mpNz9a6xejw41nkGLvLInw_10[TM__3mpNz9a6xejw41nkGLvLInw_11];
TM__3mpNz9a6xejw41nkGLvLInw_9_5[TM__3mpNz9a6xejw41nkGLvLInw_11] = &TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_11+33];
}
TM__3mpNz9a6xejw41nkGLvLInw_0[38].len = 5; TM__3mpNz9a6xejw41nkGLvLInw_0[38].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[38].sons = &TM__3mpNz9a6xejw41nkGLvLInw_9_5[0];
NTItevalmode__iWSxkwmhTDY7fh9aYmp69akQ_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[38];
TM__3mpNz9a6xejw41nkGLvLInw_0[32].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[32].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, mode);
TM__3mpNz9a6xejw41nkGLvLInw_0[32].typ = (&NTItevalmode__iWSxkwmhTDY7fh9aYmp69akQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[32].name = "mode";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[12] = &TM__3mpNz9a6xejw41nkGLvLInw_0[39];
NTItsandboxflag__6jKj8dTCDIUGegA1P2RahA_.size = sizeof(tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA);
NTItsandboxflag__6jKj8dTCDIUGegA1P2RahA_.align = NIM_ALIGNOF(tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA);
NTItsandboxflag__6jKj8dTCDIUGegA1P2RahA_.kind = 14;
NTItsandboxflag__6jKj8dTCDIUGegA1P2RahA_.base = 0;
NTItsandboxflag__6jKj8dTCDIUGegA1P2RahA_.flags = 3;
for (TM__3mpNz9a6xejw41nkGLvLInw_14 = 0; TM__3mpNz9a6xejw41nkGLvLInw_14 < 2; TM__3mpNz9a6xejw41nkGLvLInw_14++) {
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_14+40].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_14+40].offset = TM__3mpNz9a6xejw41nkGLvLInw_14;
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_14+40].name = TM__3mpNz9a6xejw41nkGLvLInw_13[TM__3mpNz9a6xejw41nkGLvLInw_14];
TM__3mpNz9a6xejw41nkGLvLInw_12_2[TM__3mpNz9a6xejw41nkGLvLInw_14] = &TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_14+40];
}
TM__3mpNz9a6xejw41nkGLvLInw_0[42].len = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[42].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[42].sons = &TM__3mpNz9a6xejw41nkGLvLInw_12_2[0];
NTItsandboxflag__6jKj8dTCDIUGegA1P2RahA_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[42];
NTItsandboxflags__lZQaLRmr1Qm22IjKsf9c5bA_.size = sizeof(tySet_tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA);
NTItsandboxflags__lZQaLRmr1Qm22IjKsf9c5bA_.align = NIM_ALIGNOF(tySet_tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA);
NTItsandboxflags__lZQaLRmr1Qm22IjKsf9c5bA_.kind = 19;
NTItsandboxflags__lZQaLRmr1Qm22IjKsf9c5bA_.base = (&NTItsandboxflag__6jKj8dTCDIUGegA1P2RahA_);
NTItsandboxflags__lZQaLRmr1Qm22IjKsf9c5bA_.flags = 3;
TM__3mpNz9a6xejw41nkGLvLInw_0[43].len = 0; TM__3mpNz9a6xejw41nkGLvLInw_0[43].kind = 0;
NTItsandboxflags__lZQaLRmr1Qm22IjKsf9c5bA_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[43];
TM__3mpNz9a6xejw41nkGLvLInw_0[39].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[39].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, features);
TM__3mpNz9a6xejw41nkGLvLInw_0[39].typ = (&NTItsandboxflags__lZQaLRmr1Qm22IjKsf9c5bA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[39].name = "features";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[13] = &TM__3mpNz9a6xejw41nkGLvLInw_0[44];
TM__3mpNz9a6xejw41nkGLvLInw_0[44].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[44].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, traceActive);
TM__3mpNz9a6xejw41nkGLvLInw_0[44].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[44].name = "traceActive";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[14] = &TM__3mpNz9a6xejw41nkGLvLInw_0[45];
TM__3mpNz9a6xejw41nkGLvLInw_0[45].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[45].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, loopIterations);
TM__3mpNz9a6xejw41nkGLvLInw_0[45].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[45].name = "loopIterations";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[15] = &TM__3mpNz9a6xejw41nkGLvLInw_0[46];
TM__3mpNz9a6xejw41nkGLvLInw_0[46].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[46].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, comesFromHeuristic);
TM__3mpNz9a6xejw41nkGLvLInw_0[46].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__3mpNz9a6xejw41nkGLvLInw_0[46].name = "comesFromHeuristic";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[16] = &TM__3mpNz9a6xejw41nkGLvLInw_0[47];
NTItupleLkey58string_value58vmcallbackT__5pg9aIYdyrJM6GlDgyTDumg_.size = sizeof(tyTuple__5pg9aIYdyrJM6GlDgyTDumg);
NTItupleLkey58string_value58vmcallbackT__5pg9aIYdyrJM6GlDgyTDumg_.align = NIM_ALIGNOF(tyTuple__5pg9aIYdyrJM6GlDgyTDumg);
NTItupleLkey58string_value58vmcallbackT__5pg9aIYdyrJM6GlDgyTDumg_.kind = 18;
NTItupleLkey58string_value58vmcallbackT__5pg9aIYdyrJM6GlDgyTDumg_.base = 0;
TM__3mpNz9a6xejw41nkGLvLInw_15_2[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[49];
TM__3mpNz9a6xejw41nkGLvLInw_0[49].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[49].offset = offsetof(tyTuple__5pg9aIYdyrJM6GlDgyTDumg, Field0);
TM__3mpNz9a6xejw41nkGLvLInw_0[49].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__3mpNz9a6xejw41nkGLvLInw_0[49].name = "Field0";
TM__3mpNz9a6xejw41nkGLvLInw_15_2[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[50];
NTIvmcallback__vkuGXw0bPP9b9cpazTHQY9bqg_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIvmcallback__vkuGXw0bPP9b9cpazTHQY9bqg_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIvmcallback__vkuGXw0bPP9b9cpazTHQY9bqg_.kind = 18;
NTIvmcallback__vkuGXw0bPP9b9cpazTHQY9bqg_.base = 0;
TM__3mpNz9a6xejw41nkGLvLInw_16_2[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[52];
TM__3mpNz9a6xejw41nkGLvLInw_0[52].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[52].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__3mpNz9a6xejw41nkGLvLInw_0[52].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__3mpNz9a6xejw41nkGLvLInw_0[52].name = "Field0";
TM__3mpNz9a6xejw41nkGLvLInw_16_2[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[53];
TM__3mpNz9a6xejw41nkGLvLInw_0[53].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[53].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__3mpNz9a6xejw41nkGLvLInw_0[53].typ = (&NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[53].name = "Field1";
TM__3mpNz9a6xejw41nkGLvLInw_0[51].len = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[51].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[51].sons = &TM__3mpNz9a6xejw41nkGLvLInw_16_2[0];
NTIvmcallback__vkuGXw0bPP9b9cpazTHQY9bqg_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[51];
TM__3mpNz9a6xejw41nkGLvLInw_0[50].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[50].offset = offsetof(tyTuple__5pg9aIYdyrJM6GlDgyTDumg, Field1);
TM__3mpNz9a6xejw41nkGLvLInw_0[50].typ = (&NTIvmcallback__vkuGXw0bPP9b9cpazTHQY9bqg_);
TM__3mpNz9a6xejw41nkGLvLInw_0[50].name = "Field1";
TM__3mpNz9a6xejw41nkGLvLInw_0[48].len = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[48].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[48].sons = &TM__3mpNz9a6xejw41nkGLvLInw_15_2[0];
NTItupleLkey58string_value58vmcallbackT__5pg9aIYdyrJM6GlDgyTDumg_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[48];
NTIseqLtupleLkey58string_value58vmcallbackTT__eJWcQvhuN2q0rM6THoByqQ_.size = sizeof(tySequence__eJWcQvhuN2q0rM6THoByqQ*);
NTIseqLtupleLkey58string_value58vmcallbackTT__eJWcQvhuN2q0rM6THoByqQ_.align = NIM_ALIGNOF(tySequence__eJWcQvhuN2q0rM6THoByqQ*);
NTIseqLtupleLkey58string_value58vmcallbackTT__eJWcQvhuN2q0rM6THoByqQ_.kind = 24;
NTIseqLtupleLkey58string_value58vmcallbackTT__eJWcQvhuN2q0rM6THoByqQ_.base = (&NTItupleLkey58string_value58vmcallbackT__5pg9aIYdyrJM6GlDgyTDumg_);
NTIseqLtupleLkey58string_value58vmcallbackTT__eJWcQvhuN2q0rM6THoByqQ_.marker = Marker_tySequence__eJWcQvhuN2q0rM6THoByqQ;
TM__3mpNz9a6xejw41nkGLvLInw_0[47].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[47].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, callbacks);
TM__3mpNz9a6xejw41nkGLvLInw_0[47].typ = (&NTIseqLtupleLkey58string_value58vmcallbackTT__eJWcQvhuN2q0rM6THoByqQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[47].name = "callbacks";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[17] = &TM__3mpNz9a6xejw41nkGLvLInw_0[54];
TM__3mpNz9a6xejw41nkGLvLInw_0[54].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[54].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, errorFlag);
TM__3mpNz9a6xejw41nkGLvLInw_0[54].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__3mpNz9a6xejw41nkGLvLInw_0[54].name = "errorFlag";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[18] = &TM__3mpNz9a6xejw41nkGLvLInw_0[55];
TM__3mpNz9a6xejw41nkGLvLInw_0[55].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[55].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, cache);
TM__3mpNz9a6xejw41nkGLvLInw_0[55].typ = (&NTIidentcache__6ZZ9cf5acLVYxUxl0ehlA1g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[55].name = "cache";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[19] = &TM__3mpNz9a6xejw41nkGLvLInw_0[56];
TM__3mpNz9a6xejw41nkGLvLInw_0[56].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[56].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, config);
TM__3mpNz9a6xejw41nkGLvLInw_0[56].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[56].name = "config";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[20] = &TM__3mpNz9a6xejw41nkGLvLInw_0[57];
TM__3mpNz9a6xejw41nkGLvLInw_0[57].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[57].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, graph);
TM__3mpNz9a6xejw41nkGLvLInw_0[57].typ = (&NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_);
TM__3mpNz9a6xejw41nkGLvLInw_0[57].name = "graph";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[21] = &TM__3mpNz9a6xejw41nkGLvLInw_0[58];
TM__3mpNz9a6xejw41nkGLvLInw_0[58].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[58].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, oldErrorCount);
TM__3mpNz9a6xejw41nkGLvLInw_0[58].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[58].name = "oldErrorCount";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[22] = &TM__3mpNz9a6xejw41nkGLvLInw_0[59];
NTIprofiler__vPk6nUD8QeNW2bHH4WZfpw_.size = sizeof(tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw);
NTIprofiler__vPk6nUD8QeNW2bHH4WZfpw_.align = NIM_ALIGNOF(tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw);
NTIprofiler__vPk6nUD8QeNW2bHH4WZfpw_.kind = 18;
NTIprofiler__vPk6nUD8QeNW2bHH4WZfpw_.base = 0;
NTIprofiler__vPk6nUD8QeNW2bHH4WZfpw_.flags = 2;
TM__3mpNz9a6xejw41nkGLvLInw_17_2[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[61];
TM__3mpNz9a6xejw41nkGLvLInw_0[61].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[61].offset = offsetof(tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw, tEnter);
TM__3mpNz9a6xejw41nkGLvLInw_0[61].typ = (&NTIfloat__w9bl9a1ul9ctRJWiMl9cNnIMvg_);
TM__3mpNz9a6xejw41nkGLvLInw_0[61].name = "tEnter";
TM__3mpNz9a6xejw41nkGLvLInw_17_2[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[62];
NTItstackframe__0GloFoQJxIWYG3W9cguBcAQ_.size = sizeof(tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ);
NTItstackframe__0GloFoQJxIWYG3W9cguBcAQ_.align = NIM_ALIGNOF(tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ);
NTItstackframe__0GloFoQJxIWYG3W9cguBcAQ_.kind = 18;
NTItstackframe__0GloFoQJxIWYG3W9cguBcAQ_.base = 0;
NTItstackframe__0GloFoQJxIWYG3W9cguBcAQ_.flags = 2;
TM__3mpNz9a6xejw41nkGLvLInw_18_5[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[64];
TM__3mpNz9a6xejw41nkGLvLInw_0[64].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[64].offset = offsetof(tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ, prc);
TM__3mpNz9a6xejw41nkGLvLInw_0[64].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[64].name = "prc";
TM__3mpNz9a6xejw41nkGLvLInw_18_5[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[65];
NTItfullreg__5wJdjCgIXFtQUOFYtApLgA_.size = sizeof(tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA);
NTItfullreg__5wJdjCgIXFtQUOFYtApLgA_.align = NIM_ALIGNOF(tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA);
NTItfullreg__5wJdjCgIXFtQUOFYtApLgA_.kind = 18;
NTItfullreg__5wJdjCgIXFtQUOFYtApLgA_.base = 0;
NTItfullreg__5wJdjCgIXFtQUOFYtApLgA_.flags = 2;
NTItregisterkind__drcwtBjsw5cM6mbg9chBM9bg_.size = sizeof(tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg);
NTItregisterkind__drcwtBjsw5cM6mbg9chBM9bg_.align = NIM_ALIGNOF(tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg);
NTItregisterkind__drcwtBjsw5cM6mbg9chBM9bg_.kind = 14;
NTItregisterkind__drcwtBjsw5cM6mbg9chBM9bg_.base = 0;
NTItregisterkind__drcwtBjsw5cM6mbg9chBM9bg_.flags = 3;
for (TM__3mpNz9a6xejw41nkGLvLInw_21 = 0; TM__3mpNz9a6xejw41nkGLvLInw_21 < 6; TM__3mpNz9a6xejw41nkGLvLInw_21++) {
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_21+67].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_21+67].offset = TM__3mpNz9a6xejw41nkGLvLInw_21;
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_21+67].name = TM__3mpNz9a6xejw41nkGLvLInw_20[TM__3mpNz9a6xejw41nkGLvLInw_21];
TM__3mpNz9a6xejw41nkGLvLInw_19_6[TM__3mpNz9a6xejw41nkGLvLInw_21] = &TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_21+67];
}
TM__3mpNz9a6xejw41nkGLvLInw_0[73].len = 6; TM__3mpNz9a6xejw41nkGLvLInw_0[73].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[73].sons = &TM__3mpNz9a6xejw41nkGLvLInw_19_6[0];
NTItregisterkind__drcwtBjsw5cM6mbg9chBM9bg_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[73];
TM__3mpNz9a6xejw41nkGLvLInw_0[66].kind = 3;
TM__3mpNz9a6xejw41nkGLvLInw_0[66].offset = offsetof(tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA, kind);
TM__3mpNz9a6xejw41nkGLvLInw_0[66].typ = (&NTItregisterkind__drcwtBjsw5cM6mbg9chBM9bg_);
TM__3mpNz9a6xejw41nkGLvLInw_0[66].name = "kind";
TM__3mpNz9a6xejw41nkGLvLInw_0[66].sons = &NimDT___5wJdjCgIXFtQUOFYtApLgA_kind[0];
TM__3mpNz9a6xejw41nkGLvLInw_0[66].len = 6;
TM__3mpNz9a6xejw41nkGLvLInw_0[74].len = 0; TM__3mpNz9a6xejw41nkGLvLInw_0[74].kind = 2;
NimDT___5wJdjCgIXFtQUOFYtApLgA_kind[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[74];
TM__3mpNz9a6xejw41nkGLvLInw_0[75].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[75].offset = offsetof(tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA, intVal);
TM__3mpNz9a6xejw41nkGLvLInw_0[75].typ = (&NTIbiggestint__Aav8dQoMlCFnZRxA0IhTHQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[75].name = "intVal";
NimDT___5wJdjCgIXFtQUOFYtApLgA_kind[2] = &TM__3mpNz9a6xejw41nkGLvLInw_0[75];
TM__3mpNz9a6xejw41nkGLvLInw_0[76].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[76].offset = offsetof(tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA, floatVal);
TM__3mpNz9a6xejw41nkGLvLInw_0[76].typ = (&NTIfloat__w9bl9a1ul9ctRJWiMl9cNnIMvg_);
TM__3mpNz9a6xejw41nkGLvLInw_0[76].name = "floatVal";
NimDT___5wJdjCgIXFtQUOFYtApLgA_kind[3] = &TM__3mpNz9a6xejw41nkGLvLInw_0[76];
TM__3mpNz9a6xejw41nkGLvLInw_0[77].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[77].offset = offsetof(tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA, node);
TM__3mpNz9a6xejw41nkGLvLInw_0[77].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[77].name = "node";
NimDT___5wJdjCgIXFtQUOFYtApLgA_kind[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[77];
NTIptrtfullreg__pX9bsRnb7gcWmGZmZ6MjgOg_.size = sizeof(tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA*);
NTIptrtfullreg__pX9bsRnb7gcWmGZmZ6MjgOg_.align = NIM_ALIGNOF(tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA*);
NTIptrtfullreg__pX9bsRnb7gcWmGZmZ6MjgOg_.kind = 21;
NTIptrtfullreg__pX9bsRnb7gcWmGZmZ6MjgOg_.base = (&NTItfullreg__5wJdjCgIXFtQUOFYtApLgA_);
NTIptrtfullreg__pX9bsRnb7gcWmGZmZ6MjgOg_.flags = 3;
TM__3mpNz9a6xejw41nkGLvLInw_0[78].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[78].offset = offsetof(tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA, regAddr);
TM__3mpNz9a6xejw41nkGLvLInw_0[78].typ = (&NTIptrtfullreg__pX9bsRnb7gcWmGZmZ6MjgOg_);
TM__3mpNz9a6xejw41nkGLvLInw_0[78].name = "regAddr";
NimDT___5wJdjCgIXFtQUOFYtApLgA_kind[4] = &TM__3mpNz9a6xejw41nkGLvLInw_0[78];
TM__3mpNz9a6xejw41nkGLvLInw_0[79].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[79].offset = offsetof(tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA, nodeAddr);
TM__3mpNz9a6xejw41nkGLvLInw_0[79].typ = (&NTIptrpnode__OjXsXEncjU0h7ZCAQTmgaw_);
TM__3mpNz9a6xejw41nkGLvLInw_0[79].name = "nodeAddr";
NimDT___5wJdjCgIXFtQUOFYtApLgA_kind[5] = &TM__3mpNz9a6xejw41nkGLvLInw_0[79];
NTItfullreg__5wJdjCgIXFtQUOFYtApLgA_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[66];
NTIseqLtfullregT__qoz9b2fDIpsvVqgQYTLWcFA_.size = sizeof(tySequence__qoz9b2fDIpsvVqgQYTLWcFA*);
NTIseqLtfullregT__qoz9b2fDIpsvVqgQYTLWcFA_.align = NIM_ALIGNOF(tySequence__qoz9b2fDIpsvVqgQYTLWcFA*);
NTIseqLtfullregT__qoz9b2fDIpsvVqgQYTLWcFA_.kind = 24;
NTIseqLtfullregT__qoz9b2fDIpsvVqgQYTLWcFA_.base = (&NTItfullreg__5wJdjCgIXFtQUOFYtApLgA_);
NTIseqLtfullregT__qoz9b2fDIpsvVqgQYTLWcFA_.flags = 2;
NTIseqLtfullregT__qoz9b2fDIpsvVqgQYTLWcFA_.marker = Marker_tySequence__qoz9b2fDIpsvVqgQYTLWcFA;
TM__3mpNz9a6xejw41nkGLvLInw_0[65].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[65].offset = offsetof(tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ, slots);
TM__3mpNz9a6xejw41nkGLvLInw_0[65].typ = (&NTIseqLtfullregT__qoz9b2fDIpsvVqgQYTLWcFA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[65].name = "slots";
TM__3mpNz9a6xejw41nkGLvLInw_18_5[2] = &TM__3mpNz9a6xejw41nkGLvLInw_0[80];
TM__3mpNz9a6xejw41nkGLvLInw_0[80].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[80].offset = offsetof(tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ, next);
TM__3mpNz9a6xejw41nkGLvLInw_0[80].typ = (&NTIpstackframe__GROwhbu9aXZcBNGpHQVFqow_);
TM__3mpNz9a6xejw41nkGLvLInw_0[80].name = "next";
TM__3mpNz9a6xejw41nkGLvLInw_18_5[3] = &TM__3mpNz9a6xejw41nkGLvLInw_0[81];
TM__3mpNz9a6xejw41nkGLvLInw_0[81].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[81].offset = offsetof(tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ, comesFrom);
TM__3mpNz9a6xejw41nkGLvLInw_0[81].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[81].name = "comesFrom";
TM__3mpNz9a6xejw41nkGLvLInw_18_5[4] = &TM__3mpNz9a6xejw41nkGLvLInw_0[82];
TM__3mpNz9a6xejw41nkGLvLInw_0[82].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[82].offset = offsetof(tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ, safePoints);
TM__3mpNz9a6xejw41nkGLvLInw_0[82].typ = (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[82].name = "safePoints";
TM__3mpNz9a6xejw41nkGLvLInw_0[63].len = 5; TM__3mpNz9a6xejw41nkGLvLInw_0[63].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[63].sons = &TM__3mpNz9a6xejw41nkGLvLInw_18_5[0];
NTItstackframe__0GloFoQJxIWYG3W9cguBcAQ_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[63];
NTIpstackframe__GROwhbu9aXZcBNGpHQVFqow_.size = sizeof(tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ*);
NTIpstackframe__GROwhbu9aXZcBNGpHQVFqow_.align = NIM_ALIGNOF(tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ*);
NTIpstackframe__GROwhbu9aXZcBNGpHQVFqow_.kind = 22;
NTIpstackframe__GROwhbu9aXZcBNGpHQVFqow_.base = (&NTItstackframe__0GloFoQJxIWYG3W9cguBcAQ_);
NTIpstackframe__GROwhbu9aXZcBNGpHQVFqow_.flags = 2;
NTIpstackframe__GROwhbu9aXZcBNGpHQVFqow_.marker = Marker_tyRef__GROwhbu9aXZcBNGpHQVFqow;
TM__3mpNz9a6xejw41nkGLvLInw_0[62].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[62].offset = offsetof(tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw, tos);
TM__3mpNz9a6xejw41nkGLvLInw_0[62].typ = (&NTIpstackframe__GROwhbu9aXZcBNGpHQVFqow_);
TM__3mpNz9a6xejw41nkGLvLInw_0[62].name = "tos";
TM__3mpNz9a6xejw41nkGLvLInw_0[60].len = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[60].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[60].sons = &TM__3mpNz9a6xejw41nkGLvLInw_17_2[0];
NTIprofiler__vPk6nUD8QeNW2bHH4WZfpw_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[60];
TM__3mpNz9a6xejw41nkGLvLInw_0[59].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[59].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, profiler);
TM__3mpNz9a6xejw41nkGLvLInw_0[59].typ = (&NTIprofiler__vPk6nUD8QeNW2bHH4WZfpw_);
TM__3mpNz9a6xejw41nkGLvLInw_0[59].name = "profiler";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[23] = &TM__3mpNz9a6xejw41nkGLvLInw_0[83];
TM__3mpNz9a6xejw41nkGLvLInw_0[83].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[83].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, templInstCounter);
TM__3mpNz9a6xejw41nkGLvLInw_0[83].typ = (&NTIrefint__9ai78kkwqt3gikTN9cpHKUVg_);
TM__3mpNz9a6xejw41nkGLvLInw_0[83].name = "templInstCounter";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[24] = &TM__3mpNz9a6xejw41nkGLvLInw_0[84];
NTILpsym_pnodeT__0y4YQo9b9byJ83c0H89bBtdRw_.size = sizeof(tyTuple__0y4YQo9b9byJ83c0H89bBtdRw);
NTILpsym_pnodeT__0y4YQo9b9byJ83c0H89bBtdRw_.align = NIM_ALIGNOF(tyTuple__0y4YQo9b9byJ83c0H89bBtdRw);
NTILpsym_pnodeT__0y4YQo9b9byJ83c0H89bBtdRw_.kind = 18;
NTILpsym_pnodeT__0y4YQo9b9byJ83c0H89bBtdRw_.base = 0;
NTILpsym_pnodeT__0y4YQo9b9byJ83c0H89bBtdRw_.flags = 2;
TM__3mpNz9a6xejw41nkGLvLInw_22_2[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[86];
TM__3mpNz9a6xejw41nkGLvLInw_0[86].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[86].offset = offsetof(tyTuple__0y4YQo9b9byJ83c0H89bBtdRw, Field0);
TM__3mpNz9a6xejw41nkGLvLInw_0[86].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__3mpNz9a6xejw41nkGLvLInw_0[86].name = "Field0";
TM__3mpNz9a6xejw41nkGLvLInw_22_2[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[87];
TM__3mpNz9a6xejw41nkGLvLInw_0[87].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[87].offset = offsetof(tyTuple__0y4YQo9b9byJ83c0H89bBtdRw, Field1);
TM__3mpNz9a6xejw41nkGLvLInw_0[87].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[87].name = "Field1";
TM__3mpNz9a6xejw41nkGLvLInw_0[85].len = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[85].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[85].sons = &TM__3mpNz9a6xejw41nkGLvLInw_22_2[0];
NTILpsym_pnodeT__0y4YQo9b9byJ83c0H89bBtdRw_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[85];
NTIseqLLpsym_pnodeTT__ztPIC2M9bqhs0KjYuE9c9cN8g_.size = sizeof(tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g*);
NTIseqLLpsym_pnodeTT__ztPIC2M9bqhs0KjYuE9c9cN8g_.align = NIM_ALIGNOF(tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g*);
NTIseqLLpsym_pnodeTT__ztPIC2M9bqhs0KjYuE9c9cN8g_.kind = 24;
NTIseqLLpsym_pnodeTT__ztPIC2M9bqhs0KjYuE9c9cN8g_.base = (&NTILpsym_pnodeT__0y4YQo9b9byJ83c0H89bBtdRw_);
NTIseqLLpsym_pnodeTT__ztPIC2M9bqhs0KjYuE9c9cN8g_.flags = 2;
NTIseqLLpsym_pnodeTT__ztPIC2M9bqhs0KjYuE9c9cN8g_.marker = Marker_tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g;
TM__3mpNz9a6xejw41nkGLvLInw_0[84].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[84].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, vmstateDiff);
TM__3mpNz9a6xejw41nkGLvLInw_0[84].typ = (&NTIseqLLpsym_pnodeTT__ztPIC2M9bqhs0KjYuE9c9cN8g_);
TM__3mpNz9a6xejw41nkGLvLInw_0[84].name = "vmstateDiff";
TM__3mpNz9a6xejw41nkGLvLInw_2_26[25] = &TM__3mpNz9a6xejw41nkGLvLInw_0[88];
NTItable__7ACYz5IhOEwzTBvwo6BO9bg_.size = sizeof(tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg);
NTItable__7ACYz5IhOEwzTBvwo6BO9bg_.align = NIM_ALIGNOF(tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg);
NTItable__7ACYz5IhOEwzTBvwo6BO9bg_.kind = 18;
NTItable__7ACYz5IhOEwzTBvwo6BO9bg_.base = 0;
NTItable__7ACYz5IhOEwzTBvwo6BO9bg_.flags = 2;
TM__3mpNz9a6xejw41nkGLvLInw_23_2[0] = &TM__3mpNz9a6xejw41nkGLvLInw_0[90];
NTIkeyvaluepairseq__E8pi9b5QNahsURYzXMjh3qw_.size = sizeof(tySequence__E8pi9b5QNahsURYzXMjh3qw*);
NTIkeyvaluepairseq__E8pi9b5QNahsURYzXMjh3qw_.align = NIM_ALIGNOF(tySequence__E8pi9b5QNahsURYzXMjh3qw*);
NTIkeyvaluepairseq__E8pi9b5QNahsURYzXMjh3qw_.kind = 24;
NTIkeyvaluepairseq__E8pi9b5QNahsURYzXMjh3qw_.base = (&NTInimver__47w2DboNEPf69aPgubZdd7Q_);
NTIkeyvaluepairseq__E8pi9b5QNahsURYzXMjh3qw_.flags = 2;
NTIkeyvaluepairseq__E8pi9b5QNahsURYzXMjh3qw_.marker = Marker_tySequence__E8pi9b5QNahsURYzXMjh3qw;
TM__3mpNz9a6xejw41nkGLvLInw_0[90].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[90].offset = offsetof(tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg, data);
TM__3mpNz9a6xejw41nkGLvLInw_0[90].typ = (&NTIkeyvaluepairseq__E8pi9b5QNahsURYzXMjh3qw_);
TM__3mpNz9a6xejw41nkGLvLInw_0[90].name = "data";
TM__3mpNz9a6xejw41nkGLvLInw_23_2[1] = &TM__3mpNz9a6xejw41nkGLvLInw_0[91];
TM__3mpNz9a6xejw41nkGLvLInw_0[91].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[91].offset = offsetof(tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg, counter);
TM__3mpNz9a6xejw41nkGLvLInw_0[91].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__3mpNz9a6xejw41nkGLvLInw_0[91].name = "counter";
TM__3mpNz9a6xejw41nkGLvLInw_0[89].len = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[89].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[89].sons = &TM__3mpNz9a6xejw41nkGLvLInw_23_2[0];
NTItable__7ACYz5IhOEwzTBvwo6BO9bg_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[89];
TM__3mpNz9a6xejw41nkGLvLInw_0[88].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[88].offset = offsetof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ, procToCodePos);
TM__3mpNz9a6xejw41nkGLvLInw_0[88].typ = (&NTItable__7ACYz5IhOEwzTBvwo6BO9bg_);
TM__3mpNz9a6xejw41nkGLvLInw_0[88].name = "procToCodePos";
TM__3mpNz9a6xejw41nkGLvLInw_0[0].len = 26; TM__3mpNz9a6xejw41nkGLvLInw_0[0].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[0].sons = &TM__3mpNz9a6xejw41nkGLvLInw_2_26[0];
NTItctx__CRPlhL1hATwZc5hefTGOQQ_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[0];
NTIpevalcontext__4IKTvAXRLrZvs9cUNEP7Z8w_.size = sizeof(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ*);
NTIpevalcontext__4IKTvAXRLrZvs9cUNEP7Z8w_.align = NIM_ALIGNOF(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ*);
NTIpevalcontext__4IKTvAXRLrZvs9cUNEP7Z8w_.kind = 22;
NTIpevalcontext__4IKTvAXRLrZvs9cUNEP7Z8w_.base = (&NTItctx__CRPlhL1hATwZc5hefTGOQQ_);
NTIpevalcontext__4IKTvAXRLrZvs9cUNEP7Z8w_.marker = Marker_tyRef__4IKTvAXRLrZvs9cUNEP7Z8w;
NTItopcode__6Md36HXDC8kz9aZEdeQ4KoQ_.size = sizeof(tyEnum_TOpcode__6Md36HXDC8kz9aZEdeQ4KoQ);
NTItopcode__6Md36HXDC8kz9aZEdeQ4KoQ_.align = NIM_ALIGNOF(tyEnum_TOpcode__6Md36HXDC8kz9aZEdeQ4KoQ);
NTItopcode__6Md36HXDC8kz9aZEdeQ4KoQ_.kind = 14;
NTItopcode__6Md36HXDC8kz9aZEdeQ4KoQ_.base = 0;
NTItopcode__6Md36HXDC8kz9aZEdeQ4KoQ_.flags = 3;
for (TM__3mpNz9a6xejw41nkGLvLInw_26 = 0; TM__3mpNz9a6xejw41nkGLvLInw_26 < 193; TM__3mpNz9a6xejw41nkGLvLInw_26++) {
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_26+92].kind = 1;
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_26+92].offset = TM__3mpNz9a6xejw41nkGLvLInw_26;
TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_26+92].name = TM__3mpNz9a6xejw41nkGLvLInw_25[TM__3mpNz9a6xejw41nkGLvLInw_26];
TM__3mpNz9a6xejw41nkGLvLInw_24_193[TM__3mpNz9a6xejw41nkGLvLInw_26] = &TM__3mpNz9a6xejw41nkGLvLInw_0[TM__3mpNz9a6xejw41nkGLvLInw_26+92];
}
TM__3mpNz9a6xejw41nkGLvLInw_0[285].len = 193; TM__3mpNz9a6xejw41nkGLvLInw_0[285].kind = 2; TM__3mpNz9a6xejw41nkGLvLInw_0[285].sons = &TM__3mpNz9a6xejw41nkGLvLInw_24_193[0];
NTItopcode__6Md36HXDC8kz9aZEdeQ4KoQ_.node = &TM__3mpNz9a6xejw41nkGLvLInw_0[285];
}

